@@ -1,7 +1,7 @@
 package Perinci::CmdLine::Lite;
 
-our $DATE = '2016-01-07'; # DATE
-our $VERSION = '1.44'; # VERSION
+our $DATE = '2016-01-21'; # DATE
+our $VERSION = '1.46'; # VERSION
 
 use 5.010001;
 # use strict; # already enabled by Mo
@@ -56,6 +56,12 @@ has validate_args => (
     is=>'rw',
     default => 1,
 );
+has use_utf8 => (
+    is=>'rw',
+    default => sub {
+        $ENV{UTF8} // 0;
+    },
+);
 
 my $formats = [qw/text text-simple text-pretty json json-pretty csv/];
 
@@ -277,6 +283,27 @@ sub hook_format_row {
 
 sub hook_display_result {
     my ($self, $r) = @_;
+
+    my $res  = $r->{res};
+    my $resmeta = $res->[3] // {};
+
+    my $handle = $r->{output_handle};
+
+    # set utf8 flag
+    my $utf8;
+    {
+        last if defined($utf8 = $ENV{UTF8});
+        if ($resmeta->{'x.hint.result_binary'}) {
+            # XXX only when format is text?
+            $utf8 = 0; last;
+        }
+        if ($r->{subcommand_data}) {
+            last if defined($utf8 = $r->{subcommand_data}{use_utf8});
+        }
+        $utf8 = $self->use_utf8;
+    }
+    binmode($handle, ":utf8") if $utf8;
+
     $self->display_result($r);
 }
 
@@ -449,7 +476,7 @@ Perinci::CmdLine::Lite - A lightweight Rinci/Riap-based command-line application
 
 =head1 VERSION
 
-This document describes version 1.44 of Perinci::CmdLine::Lite (from Perl distribution Perinci-CmdLine-Lite), released on 2016-01-07.
+This document describes version 1.46 of Perinci::CmdLine::Lite (from Perl distribution Perinci-CmdLine-Lite), released on 2016-01-21.
 
 =head1 SYNOPSIS
 
@@ -584,6 +611,15 @@ All those supported by L<Perinci::CmdLine::Base>, plus:
 
 =back
 
+=head1 RESULT METADATA
+
+All those supported by L<Perinci::CmdLine::Base>, plus:
+
+=head2 x.hint.result_binary => bool
+
+If set to true, then when formatting to C<text> formats, this class won't print
+any newline to keep the data being printed unmodified.
+
 =head1 ATTRIBUTES
 
 All the attributes of L<Perinci::CmdLine::Base>, plus:
@@ -605,6 +641,11 @@ LOG_LEVEL/TRACE/DEBUG/VERBOSE/QUIET.
 
 =head2 validate_args => bool (default: 1)
 
+=head2 use_utf8 => bool (default: from env UTF8, or 0)
+
+Whether or not to set utf8 flag on output. If undef, will default to UTF8
+environment. If that is also undef, will default to 0.
+
 =head1 METHODS
 
 All the methods of L<Perinci::CmdLine::Base>, plus:
@@ -643,22 +684,9 @@ Set the default of C<table_column_orders> in C<format_options> in result
 metadata, similar to what's implemented in L<Perinci::Result::Format> and
 L<Data::Format::Pretty::Console>.
 
-=head1 RESULT METADATA
+=head2 UTF8 => bool
 
-All those supported by L<Perinci::CmdLine::Base>, plus:
-
-=head2 x.hint.result_binary => bool
-
-If set to true, then when formatting to C<text> formats, this class won't print
-any newline to keep the data being printed unmodified.
-
-=head1 SEE ALSO
-
-L<Perinci::CmdLine::Any>
-
-L<Perinci::CmdLine::Classic>
-
-L<Perinci::CmdLine::Inline>
+To set default for C<use_utf8> attribute.
 
 =head1 HOMEPAGE
 
@@ -676,6 +704,14 @@ When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
 feature.
 
+=head1 SEE ALSO
+
+L<Perinci::CmdLine::Any>
+
+L<Perinci::CmdLine::Classic>
+
+L<Perinci::CmdLine::Inline>
+
 =head1 AUTHOR
 
 perlancar <perlancar@cpan.org>
