@@ -1,7 +1,7 @@
 package Perinci::CmdLine::Util::Config;
 
-our $DATE = '2016-01-07'; # DATE
-our $VERSION = '1.44'; # VERSION
+our $DATE = '2016-01-21'; # DATE
+our $VERSION = '1.46'; # VERSION
 
 use 5.010;
 use strict;
@@ -92,6 +92,7 @@ sub get_args_from_config {
 
     my $r       = $fargs{r};
     my $conf    = $fargs{config};
+    my $progn   = $fargs{program_name};
     my $scn     = $fargs{subcommand_name} // '';
     my $profile = $fargs{config_profile};
     my $args    = $fargs{args} // {};
@@ -126,11 +127,16 @@ sub get_args_from_config {
         my $sect_scn     = $keyvals{subcommand} // '';
         my $sect_profile = $keyvals{profile};
 
+        # if there is a subcommand name, use section with no subcommand=... or
+        # the matching subcommand
         if (length $scn) {
             next if length($sect_scn) && $sect_scn ne $scn;
         } else {
             next if length $sect_scn;
         }
+
+        # if user chooses a profile, only use section with no profile=... or the
+        # matching profile
         if (defined $profile) {
             next if defined($sect_profile) && $sect_profile ne $profile;
             $found = 1 if defined($sect_profile) && $sect_profile eq $profile;
@@ -138,6 +144,11 @@ sub get_args_from_config {
             next if defined($sect_profile);
         }
 
+        # only use section marked with program=... if the program name matches
+        if (defined($progn) && defined($keyvals{program})) {
+            next unless $progn eq $keyvals{program};
+        }
+
         my $as = $meta->{args} // {};
         for my $k (keys %{ $conf->{$section} }) {
             my $v = $conf->{$section}{$k};
@@ -193,7 +204,7 @@ Perinci::CmdLine::Util::Config - Utility routines related to config files
 
 =head1 VERSION
 
-This document describes version 1.44 of Perinci::CmdLine::Util::Config (from Perl distribution Perinci-CmdLine-Lite), released on 2016-01-07.
+This document describes version 1.46 of Perinci::CmdLine::Util::Config (from Perl distribution Perinci-CmdLine-Lite), released on 2016-01-21.
 
 =head1 FUNCTIONS
 
